<?php
namespace frontend\controllers;

use Yii;
use common\models\LoginForm;
use common\models\OrdersAudit;
use frontend\models\PasswordResetRequestForm;
use frontend\models\ResetPasswordForm;
use frontend\models\SignupForm;
use frontend\models\ContactForm;
use yii\base\InvalidParamException;
use yii\web\BadRequestHttpException;
use yii\web\Controller;
use yii\filters\VerbFilter;
use yii\filters\AccessControl;

/**
 * Site controller
 */
class SiteController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'only' => ['logout', 'signup'],
                'rules' => [
                    [
                        'actions' => ['signup'],
                        'allow' => true,
                        'roles' => ['?'],
                    ],
                    [
                        'actions' => ['logout'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction',
            ],
            'captcha' => [
                'class' => 'yii\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

    /**
     * Displays homepage.
     *
     * @return mixed
     */
    public function actionIndex()
    {
	    // Get clients
	    $clientsModel = new \frontend\models\Clients();
	    $clients = $clientsModel->find()->all(); //(['visible'=>1]);

	    $ordersAuditModel = new \common\models\OrdersAudit();

	    return $this->render('frontpage', [
		    'clients' => $clients,
		    'ordersauditmodel' => $ordersAuditModel
	    ]);
    }

	/**
	 * Displays team or team-member page.
	 *
	 * @return mixed
	 */
	public function actionTeam($id = null)
	{
		if (empty($id)) {
			// Get team members
			$teamModel = new \frontend\models\Team();
			$members   = $teamModel->find()->all();

			return $this->render( 'team', [
				'members' => $members
			] );
		} else {
			// Get team member
			$teamModel = new \frontend\models\Team();
			$data = $teamModel->findOne(['id' => $id]);
			return $this->render('teamitem', [
				'member' => $data
			]);
		}
	}

	/**
	 * Displays services pages.
	 */

	public function actionServiceitem($name = null)
	{
		$ordersAuditModel = new \common\models\OrdersAudit();
		return $this->render(
			'services/'. $name,
			[
				'ordersAuditModel' => $ordersAuditModel
			]
		);
	}


	/**
	 * Displays/action audit form.
	 */

	public function actionAuditform($result = null)
	{
		$model = new OrdersAudit();

		if ($result == 'success') {
			return $this->render(
				'orders_audit_success'
			);
		}

		if ($model->load(Yii::$app->request->post()) && $model->validate()) {
			$model->setDefaults();
			$model->sendEmail('karnovsky.a@gmail.com');
			$model->save();
			return $this->redirect(['auditform', 'result' => 'success']);
		}

		return $this->render(
			'orders_audit',
			[
				'model' => $model
			]
		);
	}


    /**
     * Logs in a user.
     *
     * @return mixed
     */
    public function actionLogin()
    {
        if (!\Yii::$app->user->isGuest) {
            return $this->goHome();
        }

        $model = new LoginForm();
        if ($model->load(Yii::$app->request->post()) && $model->login()) {
            return $this->goBack();
        } else {
            return $this->render('login', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Logs out the current user.
     *
     * @return mixed
     */
    public function actionLogout()
    {
        Yii::$app->user->logout();

        return $this->goHome();
    }

    /**
     * Displays contact page.
     *
     * @return mixed
     */
    public function actionContact()
    {
        $model = new ContactForm();
        if ($model->load(Yii::$app->request->post()) && $model->validate()) {
            if ($model->sendEmail(Yii::$app->params['adminEmail'])) {
                Yii::$app->session->setFlash('success', 'Thank you for contacting us. We will respond to you as soon as possible.');
            } else {
                Yii::$app->session->setFlash('error', 'There was an error sending email.');
            }

            return $this->refresh();
        } else {
            return $this->render('contact', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Displays vacancies page.
     *
     * @return mixed
     */
    public function actionVacancies()
    {
	    // Get clients
	    $clientsModel = new \frontend\models\Clients();
	    $clients = $clientsModel->find()->all(); //(['visible'=>1]);
	    return $this->render('vacancies', [
		    'clients' => $clients,
	    ]);
    }

	public function actionCount_form()
	{
		if(isset($_GET)){
			$page    = !empty($_GET['p']) ? $_GET['p'] : 'form';
			$subpage = !empty($_GET['sp']) ? $_GET['sp'] : 'index';
			$action = !empty($_GET['a']) ? $_GET['a'] : $subpage;
			include_once __DIR__ . '/../web/count_form/app/data/'. $page .'.php';
			$class   = 'count_form\app\data\\'.$page;
			$object = new $class();
			$data = $object->$action();
		}

		include_once __DIR__ .'count_form/app/view/main_page.php';
		exit;
	}

    /**
     * Signs user up.
     *
     * @return mixed
     */
    public function actionSignup()
    {
        $model = new SignupForm();
        if ($model->load(Yii::$app->request->post())) {
            if ($user = $model->signup()) {
                if (Yii::$app->getUser()->login($user)) {
                    return $this->goHome();
                }
            }
        }

        return $this->render('signup', [
            'model' => $model,
        ]);
    }

    /**
     * Requests password reset.
     *
     * @return mixed
     */
    public function actionRequestPasswordReset()
    {
        $model = new PasswordResetRequestForm();
        if ($model->load(Yii::$app->request->post()) && $model->validate()) {
            if ($model->sendEmail()) {
                Yii::$app->session->setFlash('success', 'Check your email for further instructions.');

                return $this->goHome();
            } else {
                Yii::$app->session->setFlash('error', 'Sorry, we are unable to reset password for email provided.');
            }
        }

        return $this->render('requestPasswordResetToken', [
            'model' => $model,
        ]);
    }

    /**
     * Resets password.
     *
     * @param string $token
     * @return mixed
     * @throws BadRequestHttpException
     */
    public function actionResetPassword($token)
    {
        try {
            $model = new ResetPasswordForm($token);
        } catch (InvalidParamException $e) {
            throw new BadRequestHttpException($e->getMessage());
        }

        if ($model->load(Yii::$app->request->post()) && $model->validate() && $model->resetPassword()) {
            Yii::$app->session->setFlash('success', 'New password was saved.');

            return $this->goHome();
        }

        return $this->render('resetPassword', [
            'model' => $model,
        ]);
    }
}
